==> dde-daemon_6.0.48.tar.xz: BUILD/misc/ts/org.deepin.dde.accounts.policy/policy_gl_ES.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="gl_ES" version="2.1">
	<context>
		<name>policy</name>
		<message>
			<location filename="org.deepin.dde.accounts.change-own-user-data!message" line="0"/>
			<source>Authentication is required to change your own user data</source>
			<translation>Requírese autenticación para cambiar os seus datos de usuario</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.change-own-user-data!description" line="0"/>
			<source>Change your own user data</source>
			<translation>Cambiar os seus datos de usuario</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.user-administration!message" line="0"/>
			<source>Authentication is required to change user data</source>
			<translation>Requírese autenticación para cambiar os datos de usuario</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.user-administration!description" line="0"/>
			<source>Manage user accounts</source>
			<translation>Xestionar as contas de usuario</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.enable-auto-login!message" line="0"/>
			<source>Authentication is required to enable auto login</source>
			<translation>Requírese autenticación para habilitar o inicio automático</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.enable-auto-login!description" line="0"/>
			<source>Enable Auto Login</source>
			<translation>Habilitar o inicio automático</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.disable-auto-login!message" line="0"/>
			<source>Authentication is required to disable auto login</source>
			<translation>Requírese autenticación para inhabilitar o inicio automático</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.disable-auto-login!description" line="0"/>
			<source>Disable Auto Login</source>
			<translation>Inhabilitar o inicio automático</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.enable-nopass-login!message" line="0"/>
			<source>Authentication is required to enable login without password</source>
			<translation>Requírese autenticación para habilitar o inicio sen contrasinal</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.enable-nopass-login!description" line="0"/>
			<source>Enable Login without password</source>
			<translation>Habilitar o inicio sen contrasinal</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.disable-nopass-login!message" line="0"/>
			<source>Authentication is required to disable login without password</source>
			<translation>Requírese autenticación para inhabilitar o inicio sen contrasinal</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.disable-nopass-login!description" line="0"/>
			<source>Disable Login without password</source>
			<translation>Inhabilitar o incio sen contrasinal</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.set-keyboard-layout!message" line="0"/>
			<source>Authentication is required to set keyboard layout</source>
			<translation>Requírese autenticación para establecer a disposición do teclado</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.set-keyboard-layout!description" line="0"/>
			<source>Set keyboard layout</source>
			<translation>Establecer a disposición do teclado</translation>
		</message>
	</context>
</TS>

==> dde-daemon_6.1.45.tar.xz: BUILD/misc/ts/org.deepin.dde.accounts.policy/policy_gl_ES.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="gl_ES">
	<context>
		<name>policy</name>
		<message>
			<location filename="org.deepin.dde.accounts.change-own-user-data!message" line="0"/>
			<source>Authentication is required to change your own user data</source>
			<translation>Requírese autenticación para cambiar os seus datos de usuario</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.change-own-user-data!description" line="0"/>
			<source>Change your own user data</source>
			<translation>Cambiar os seus datos de usuario</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.user-administration!message" line="0"/>
			<source>Authentication is required to change user data</source>
			<translation>Requírese autenticación para cambiar os datos de usuario</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.user-administration!description" line="0"/>
			<source>Manage user accounts</source>
			<translation>Xestionar as contas de usuario</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.enable-auto-login!message" line="0"/>
			<source>Authentication is required to enable auto login</source>
			<translation>Requírese autenticación para habilitar o inicio automático</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.enable-auto-login!description" line="0"/>
			<source>Enable Auto Login</source>
			<translation>Habilitar o inicio automático</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.disable-auto-login!message" line="0"/>
			<source>Authentication is required to disable auto login</source>
			<translation>Requírese autenticación para inhabilitar o inicio automático</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.disable-auto-login!description" line="0"/>
			<source>Disable Auto Login</source>
			<translation>Inhabilitar o inicio automático</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.enable-quick-login!message" line="0"/>
			<source>Authentication is required to enable quick login</source>
			<translation type="unfinished"/>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.enable-quick-login!description" line="0"/>
			<source>Enable Quick Login</source>
			<translation type="unfinished"/>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.disable-quick-login!message" line="0"/>
			<source>Authentication is required to disable quick login</source>
			<translation type="unfinished"/>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.disable-quick-login!description" line="0"/>
			<source>Disable Quick Login</source>
			<translation type="unfinished"/>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.enable-wechat-auth!message" line="0"/>
			<source>Authentication is required to enable WeChat code login</source>
			<translation type="unfinished"/>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.enable-wechat-auth!description" line="0"/>
			<source>Enable WeChat Code Login</source>
			<translation type="unfinished"/>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.disable-wechat-auth!message" line="0"/>
			<source>Authentication is required to disable WeChat code login</source>
			<translation type="unfinished"/>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.disable-wechat-auth!description" line="0"/>
			<source>Disable WeChat Code Login</source>
			<translation type="unfinished"/>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.enable-nopass-login!message" line="0"/>
			<source>Authentication is required to enable login without password</source>
			<translation>Requírese autenticación para habilitar o inicio sen contrasinal</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.enable-nopass-login!description" line="0"/>
			<source>Enable Login without password</source>
			<translation>Habilitar o inicio sen contrasinal</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.disable-nopass-login!message" line="0"/>
			<source>Authentication is required to disable login without password</source>
			<translation>Requírese autenticación para inhabilitar o inicio sen contrasinal</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.disable-nopass-login!description" line="0"/>
			<source>Disable Login without password</source>
			<translation>Inhabilitar o incio sen contrasinal</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.set-keyboard-layout!message" line="0"/>
			<source>Authentication is required to set keyboard layout</source>
			<translation>Requírese autenticación para establecer a disposición do teclado</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.set-keyboard-layout!description" line="0"/>
			<source>Set keyboard layout</source>
			<translation>Establecer a disposición do teclado</translation>
		</message>
	</context>
</TS>
